@@ -53,6 +53,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_s3
@@ -109,7 +111,7 @@ class CfnGitHubRepository(
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]] = None,
+        code: typing.Optional[typing.Union[typing.Union["CfnGitHubRepository.CodeProperty", typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -129,6 +131,10 @@ class CfnGitHubRepository(
         :param repository_access_token: The GitHub user's personal access token for the GitHub repository.
         :param repository_description: A comment or description about the new repository. This description is displayed in GitHub after the repository is created.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnGitHubRepository.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CfnGitHubRepositoryProps(
             repository_name=repository_name,
             repository_owner=repository_owner,
@@ -148,6 +154,9 @@ class CfnGitHubRepository(
 
         :param inspector: - tree inspector to collect and process attributes.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnGitHubRepository.inspect)
+            check_type(argname="argument inspector", value=inspector, expected_type=type_hints["inspector"])
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
@@ -158,6 +167,9 @@ class CfnGitHubRepository(
         '''
         :param props: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnGitHubRepository._render_properties)
+            check_type(argname="argument props", value=props, expected_type=type_hints["props"])
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
     @jsii.python.classproperty # type: ignore[misc]
@@ -182,6 +194,9 @@ class CfnGitHubRepository(
 
     @repository_name.setter
     def repository_name(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_name").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryName", value)
 
     @builtins.property # type: ignore[misc]
@@ -197,6 +212,9 @@ class CfnGitHubRepository(
 
     @repository_owner.setter
     def repository_owner(self, value: builtins.str) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_owner").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryOwner", value)
 
     @builtins.property # type: ignore[misc]
@@ -215,6 +233,9 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union["CfnGitHubRepository.CodeProperty", aws_cdk.core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "code").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "code", value)
 
     @builtins.property # type: ignore[misc]
@@ -228,6 +249,9 @@ class CfnGitHubRepository(
 
     @connection_arn.setter
     def connection_arn(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "connection_arn").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "connectionArn", value)
 
     @builtins.property # type: ignore[misc]
@@ -248,6 +272,9 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "enable_issues").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "enableIssues", value)
 
     @builtins.property # type: ignore[misc]
@@ -268,6 +295,9 @@ class CfnGitHubRepository(
         self,
         value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "is_private").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "isPrivate", value)
 
     @builtins.property # type: ignore[misc]
@@ -281,6 +311,9 @@ class CfnGitHubRepository(
 
     @repository_access_token.setter
     def repository_access_token(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_access_token").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryAccessToken", value)
 
     @builtins.property # type: ignore[misc]
@@ -296,6 +329,9 @@ class CfnGitHubRepository(
 
     @repository_description.setter
     def repository_description(self, value: typing.Optional[builtins.str]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(CfnGitHubRepository, "repository_description").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "repositoryDescription", value)
 
     @jsii.data_type(
@@ -307,7 +343,7 @@ class CfnGitHubRepository(
         def __init__(
             self,
             *,
-            s3: typing.Union[aws_cdk.core.IResolvable, "CfnGitHubRepository.S3Property"],
+            s3: typing.Union[aws_cdk.core.IResolvable, typing.Union["CfnGitHubRepository.S3Property", typing.Dict[str, typing.Any]]],
         ) -> None:
             '''The ``Code`` property type specifies information about code to be committed.
 
@@ -334,6 +370,9 @@ class CfnGitHubRepository(
                     )
                 )
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(CfnGitHubRepository.CodeProperty.__init__)
+                check_type(argname="argument s3", value=s3, expected_type=type_hints["s3"])
             self._values: typing.Dict[str, typing.Any] = {
                 "s3": s3,
             }
@@ -403,6 +442,11 @@ class CfnGitHubRepository(
                     object_version="objectVersion"
                 )
             '''
+            if __debug__:
+                type_hints = typing.get_type_hints(CfnGitHubRepository.S3Property.__init__)
+                check_type(argname="argument bucket", value=bucket, expected_type=type_hints["bucket"])
+                check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+                check_type(argname="argument object_version", value=object_version, expected_type=type_hints["object_version"])
             self._values: typing.Dict[str, typing.Any] = {
                 "bucket": bucket,
                 "key": key,
@@ -471,7 +515,7 @@ class CfnGitHubRepositoryProps:
         *,
         repository_name: builtins.str,
         repository_owner: builtins.str,
-        code: typing.Optional[typing.Union[CfnGitHubRepository.CodeProperty, aws_cdk.core.IResolvable]] = None,
+        code: typing.Optional[typing.Union[typing.Union[CfnGitHubRepository.CodeProperty, typing.Dict[str, typing.Any]], aws_cdk.core.IResolvable]] = None,
         connection_arn: typing.Optional[builtins.str] = None,
         enable_issues: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         is_private: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
@@ -519,6 +563,16 @@ class CfnGitHubRepositoryProps:
                 repository_description="repositoryDescription"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CfnGitHubRepositoryProps.__init__)
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument repository_owner", value=repository_owner, expected_type=type_hints["repository_owner"])
+            check_type(argname="argument code", value=code, expected_type=type_hints["code"])
+            check_type(argname="argument connection_arn", value=connection_arn, expected_type=type_hints["connection_arn"])
+            check_type(argname="argument enable_issues", value=enable_issues, expected_type=type_hints["enable_issues"])
+            check_type(argname="argument is_private", value=is_private, expected_type=type_hints["is_private"])
+            check_type(argname="argument repository_access_token", value=repository_access_token, expected_type=type_hints["repository_access_token"])
+            check_type(argname="argument repository_description", value=repository_description, expected_type=type_hints["repository_description"])
         self._values: typing.Dict[str, typing.Any] = {
             "repository_name": repository_name,
             "repository_owner": repository_owner,
@@ -696,6 +750,17 @@ class GitHubRepositoryProps:
                 contents_key="import.zip"
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitHubRepositoryProps.__init__)
+            check_type(argname="argument access_token", value=access_token, expected_type=type_hints["access_token"])
+            check_type(argname="argument contents_bucket", value=contents_bucket, expected_type=type_hints["contents_bucket"])
+            check_type(argname="argument contents_key", value=contents_key, expected_type=type_hints["contents_key"])
+            check_type(argname="argument owner", value=owner, expected_type=type_hints["owner"])
+            check_type(argname="argument repository_name", value=repository_name, expected_type=type_hints["repository_name"])
+            check_type(argname="argument contents_s3_version", value=contents_s3_version, expected_type=type_hints["contents_s3_version"])
+            check_type(argname="argument description", value=description, expected_type=type_hints["description"])
+            check_type(argname="argument enable_issues", value=enable_issues, expected_type=type_hints["enable_issues"])
+            check_type(argname="argument visibility", value=visibility, expected_type=type_hints["visibility"])
         self._values: typing.Dict[str, typing.Any] = {
             "access_token": access_token,
             "contents_bucket": contents_bucket,
@@ -965,6 +1030,10 @@ class GitHubRepository(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(GitHubRepository.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = GitHubRepositoryProps(
             access_token=access_token,
             contents_bucket=contents_bucket,
